@@ -1,2 +1,2 @@
 # this file is needed to make this directory a python package
-from dependencies import Dependencies
+from .dependencies import Dependencies
